@@ -1161,10 +1161,10 @@ setMethodS3("getDetails", "Class", function(this, private=FALSE, ...) {
       s <- paste(s, indentStr, modifiers[k], " ", fields[k], "\n", sep="");
   }
 
-  formalsToString <- function(methodName, isConstructor=FALSE) {
-    args <- argsToString(Class, method, argOffset);
-    s <- paste(sep="", s, methodName, "(", args, ")\n");
-  } ## formalsToString(...)
+##   formalsToString <- function(methodName, isConstructor=FALSE) {
+##     args <- argsToString(Class, method, argOffset);
+##     s <- paste(sep="", s, methodName, "(", args, ")\n");
+##   } ## formalsToString(...)
 
   methodsPerClass <- getMethods(this, private=private);
   if (length(methodsPerClass) > 0) {
@@ -1212,8 +1212,8 @@ setMethodS3("getDetails", "Class", function(this, private=FALSE, ...) {
 # @title "Makes the fields and methods of an Class accessable via the \$ and the [[ operator"
 #
 # \usage{
-#   "$.Class"(this, name)
-#   "[[.Class"(this, name)
+#   \method{$}{Class}(this, name)
+#   \method{[[}{Class}(this, name)
 # }
 #
 # \description{
@@ -1327,8 +1327,8 @@ setMethodS3("$", "Class", function(this, name) {
 # @title "Makes the fields and methods of an Class assignable via the \$<- and the [[<- operator"
 #
 # \usage{
-#   "$<-.Class"(this, name, value)
-#   "[[<-.Class"(this, name, value)
+#   \method{$}{Class}(this, name) <- value
+#   \method{[[}{Class}(this, name) <- value
 # }
 #
 # \description{
@@ -1435,6 +1435,9 @@ setMethodS3("[[<-", "Class", function(this, name, value) {
 
 ############################################################################
 # HISTORY:
+# 2007-06-09
+# o Removed internal function formalsToString() of getDetails() for class
+#   Class, because it was never used.
 # 2007-01-05
 # o BUG FIX: getMethods(..., private=FALSE) would return private methods,
 #   and private=TRUE would remove them.  It should be the otherway around.
