@@ -383,7 +383,6 @@ setMethodS3("getVersion", "Package", function(this, ...) {
 
 #########################################################################/**
 # @RdocMethod getDataPath
-# @aliasmethod getData
 #
 # @title "Gets the path to the data (data/) directory of this package"
 #
@@ -412,12 +411,6 @@ setMethodS3("getDataPath", "Package", function(this, ...) {
 })
 
 
-# Virtual field $data, because a lot of old packages uses it.
-setMethodS3("getData", "Package", function(this, ...) {
-  getDataPath(this);
-}, private=TRUE, deprecated=TRUE)
-
-
 
 #########################################################################/**
 # @RdocMethod getDocPath
@@ -712,7 +705,7 @@ setMethodS3("isLoaded", "Package", function(this, ...) {
 # }
 #*/#########################################################################
 setMethodS3("load", "Package", function(this, ...) {
-  eval(substitute(library(pkg), list=list(pkg=as.name(getName(this)))));
+  eval(substitute(library(pkg), list(pkg=as.name(getName(this)))));
   isLoaded(this);
 })
 
@@ -1544,7 +1537,6 @@ setMethodS3("update", "Package", function(object, contribUrl=c(getContribUrl(thi
     tmpfile <- tempfile();
     on.exit(unlink(tmpfile), add=TRUE);
     for (url in contribUrl) {
-print(url);
       tryCatch({
         if (force) {
           install.packages(pkgs, contriburl=url);
@@ -1559,14 +1551,14 @@ print(url);
             break;
           }
         } # if (force)
-      }, warning=function(warn) {
-      }, error=function(ex) {
-         print(error);
+      }, warning = function(warn) {
+      }, error = function(ex) {
+        print(ex);
       })
     } # for (url ...)
     
     if (!found) {
-      require(R.oo);  # In case it was unloaded!
+      require("R.oo");  # In case it was unloaded!
       throw(InternalErrorException("Could not update package ", getName(this), " v", getVersion(this), " since none of the URLs available (", paste(contribUrl, collapse=", "), ") seems to contain no R packages or bundles, i.e. no PACKAGE file was found. The URLs were extracted from the DESCRIPTION file of the package.", package=this));
     }
   }
@@ -1577,6 +1569,13 @@ print(url);
 
 ############################################################################
 # HISTORY:
+# 2007-06-09
+# o BUG FIX: Queried non-existing object 'error' instead of 'ex' in
+#   the exception handling of update() of the Package class.
+# o Removed (incorrect) argument name 'list' from all substitute() calls.
+# 2007-06-01
+# o Removed already deprecated getData() because there might be a name 
+#   clash with the 'nlme' package.
 # 2006-07-13
 # o Now update() returns invisibly.
 # o BUG FIX: update(R.oo) would throw an error and package was detached.
